@@ -17,7 +17,7 @@
  */
 
 #define NL_MAJOR 2
-#define NL_MINOR 0
+#define NL_MINOR 2
 #define NL_REV   5
-#define NL_DATE  "Jul 11, 2003"
-#define VERSION  "2.0.5"
+#define NL_DATE  "Mar 10, 2006"
+#define VERSION  "2.2.5"
